=======
History
=======

1.0.0 (2018-06-28)
------------------

* First release on PyPI.
* Stock class implemented.
* Portfolio class implemented.
* Minimum Variance Portfolio optimization
* Efficient Frontier evaluation
* Tangency Portfolio for a given risk free return rate


1.0.1 (2018-06-28)
------------------

* Minor ajusts.


1.0.2 (2018-06-28)
------------------

* Minor ajusts.


1.1.0 (2018-08-05)
------------------

* Portfalio evaluation given actual stocks returns.


1.2.0 (2019-03-27)
------------------

* Calculating the optimization problem manualy so cvxopt is no longer necessary.


1.3.0 (2019-03-30)
------------------

* Use pseudo inverse when covariance matrix is close to singular.


1.3.1 (2019-03-31)
------------------

* Fix docs URL on README.